function [ s_TD1 ] = InitAcquireDefinition( ~ )
%INITACQUIREDEFINITION Initialise TD1

%%%%%%% Setup structure for TD1 %%%%%%%
s_TD1.AcquireMode       = uint16(3); %0 = Single, 1= automatic, 2 = triggered, 3 = stop (3 required for Driver Init)
s_TD1.AcquisitionMode   = uint16(0); %0 = sampled, 1= Peak captured, 2 = Filtered, 3= Repetitive, 4= Waveform avg
s_TD1.Acquirer          = uint16(4); %Always set to 4 for cleverscopes
s_TD1.TransferChans     = uint16(2); %Always set to 2 transfers all channels
s_TD1.AMaxScale         = double(5); %+5Volts. Ensure more than A Min
s_TD1.AMinScale         = double(-5);%-5Volts. Ensure less than A Max
s_TD1.BMaxScale         = double(5); %+5Volts. Ensure more than B Min
s_TD1.BMinScale         = double(-5);%-5Volts. Ensure less than B Max
s_TD1.AProbe            = uint16(0); %0 = x1, 1 = x10, 2 = x100, 3 = x1000, 4 = x20, 5 = x50, 6 = x200
s_TD1.BProbe            = uint16(0); %0 = x1, 1 = x10, 2 = x100, 3 = x1000, 4 = x20, 5 = x50, 6 = x200
s_TD1.ACoupling         = uint16(0); %0 = AC, 1= DC
s_TD1.BCoupling         = uint16(0); %0 = AC, 1= DC
s_TD1.ABandwidth        = uint16(0); %0=no filter. See 'Cscope Control Driver DLL description.pdf' for options
s_TD1.BBandwidth        = uint16(0); %0=no filter. See 'Cscope Control Driver DLL description.pdf' for options
s_TD1.TriggerSource     = uint16(0); %0 = A chan, 1 = B chan, 2 = Ext Trigger, 3 = Dig Input, 4 = Link Port
s_TD1.TriggerAmplitude  = double(1); %1Volt
s_TD1.ATriggerAmplitude	= double(0); %Not used by driver
s_TD1.BTriggerAmplitude	= double(0); %Not used by driver
s_TD1.TriggerFilter     = uint16(0); %0=no filter. See 'Cscope Control Driver DLL description.pdf' for options
s_TD1.TrigSlope         = uint8(0);  %0 = rising, 1 = falling
s_TD1.TriggerHoldoff    = double(0); %Not used by driver
s_TD1.DigPatternRqd     = uint8(0);  %0 = not required. 1=required
s_TD1.DigPattern        = uint32(0); %See 'Cscope Control Driver DLL description.pdf' for options
s_TD1.ExtTrigThreshold  = double(0); %Sets the amplitude of the external trigger input, -6..+18V
s_TD1.DigInputThreshold = double(2); %Sets the amplitude of the digital input threshold, 0 .. 10V
s_TD1.StartTime         = double(-0.005); %-10ms. Sets the start time relative to the trigger
s_TD1.StopTime          = double(0.005); %10ms. Sets the stop time relative to the trigger
s_TD1.SampleInterval    = double(0); %Not used by driver
s_TD1.Port              = uint16(0); %Not used by driver
s_TD1.NumDivisions      = int16(0);  %Not used by driver
s_TD1.NumSeqFrames      = int16(1);  %Sets the number of frames captured sequentially. Read the 'Cscope Control Driver DLL description.pdf'.
s_TD1.NumBuffers        = int32(2);  %Sets the number of buffers allocated for frame capture. Must be at least num waveform averages + 1.
s_TD1.SigGenFreq        = double(500); %1kHz. Set the signal generator frequency in Hz. Range is 0.003..10e6 Hz.
s_TD1.SigGenAmp         = double(1); %3V. P-P Amplitude of signal generator output. Range is 0..8V
s_TD1.SigGenOffset      = double(0); %0V. Offset of signal generator output. Range is 5..+5V
s_TD1.SigGenWaveform    = uint16(0); %Sets the signal generator waveform. 0 = sine, 1= triangle, 2 = square, 3 = DC, 4 = 0V.
s_TD1.SigGenSweep       = uint16(0); %Not used by driver
s_TD1.SigGenFunc        = uint16(0); %0 means normal sig gen use, 1 means step the sig gen upwards by Sig Gen Freq Step automatically following a trigger.
s_TD1.SigGenFreq2       = double(0); %Not used by driver
s_TD1.SigGenPhase       = double(0); %Not used by driver
s_TD1.Trig2Function     = uint16(0); %0=Not used. See 'Cscope Control Driver DLL description.pdf' for options
s_TD1.MinTriggerPeriod  = double(10e-9); %For Trig2. Sets the min period. 0..22 secs, resolution is 10 ns.
s_TD1.MaxTriggerPeriod  = double(1); %For Trig2. Sets the max period. 0..22 secs, resolution is 10 ns.
s_TD1.TriggerCount      = uint32(0); %For Trig2. Sets the number of counts for counting. 0..4,294,967,295
s_TD1.Trig2Slope        = uint8(0);  %For Trig2. Sets the slope for trigger 2. 0 = rising, 1 = falling
s_TD1.Trig2SourceChan   = uint16(0); %For Trig2. Sets the trigger 2 source channel. 0 = A chan, 1 = B chan, 2 = Ext Trigger, 3 = Dig Input, 4 = Link Port
s_TD1.Trig2Level        = double(0); %For Trig2. Sets the trigger 2 threshold level.
s_TD1.DigPattern2Rqd    = uint8(0);  %For Trig2. Sets if Trigger 2 is qualified by the pattern.
s_TD1.DigPattern2       = uint32(0); %For Trig2. Defines the trigger 2 digital pattern.
s_TD1.Trigger2Source    = uint16(0); %For Trig2. 0 = Trigger 1 inverted, 1= Use the Trigger 2 definition
s_TD1.WaveformAverages  = int32(1);  %Sets how many waveforms to average in acquisition unit if acquisition mode = waveform avg. Values are 1, 4, 16, 64 and 128
s_TD1.ValueChanged      = int32(1);  %Change this value to cause the driver to check for changes in all the values in this data structure. If not changed, data structure values will not update.
s_TD1.FreqSpan          = double(0); %Not used by driver
s_TD1.FreqRes           = double(0); %Not used by driver
s_TD1.Duration          = double(0); %Not used by driver
s_TD1.Resolution        = double(0); %Not used by driver
s_TD1.LinkPort          = uint8(0);  %See 'Cscope Control Driver DLL description.pdf' for options
s_TD1.ExtSampleClock    = uint8(0);  %See 'Cscope Control Driver DLL description.pdf' for options
s_TD1.FSpare2           = uint8(0);  %Reserved
s_TD1.FSpare3           = uint8(0);  %Reserved
s_TD1.FSpare4           = uint8(0);  %Reserved
s_TD1.SamplerResolution = uint16(0); %Sets the sampler resolution to be used, 0 = 10 bits, 1 = 12 bits, 2 = 14 bits. Will clip to maximum resolution available.
s_TD1.IntfSource        = uint16(0); %Source for connections  0 = USB, 1 = Ethernet  Open specified IP address, 2 = Find first connected cleverscope, 3 = find Cleverscope with given serial number.
s_TD1.UpdateRate        = uint16(0); %Not used by driver
s_TD1.TransferSize      = uint16(0); %Use 0 to transfer one frame. Use 6 to transfer all the frames in a sequential capture as one array
s_TD1.SigGenFreqStep    = double(0); %Frequency increment used when acquisition unit automatically steps the signal generator frequency following a trigger, if Sig gen Func = 1.
s_TD1.TCPAdr            = uint32(0); %TCP address of acquisition unit. Format is bb.bb.bb.bb
s_TD1.TCPPort           = uint32(0); %TCP port used for acquisition unit.
s_TD1.CAUSerNumHi       = uint32(0); %See 'Cscope Control Driver DLL description.pdf' for options
s_TD1.CAUSerNumLo       = uint32(0); %See 'Cscope Control Driver DLL description.pdf' for options
s_TD1.FunctionNumber    = double(0); %Should not be used directly. Leave as 0.
s_TD1.FunctionParameter = double(0); %Should not be used directly. Leave as 0.
s_TD1.FunctionResult    = double(0); %Should not be used directly. Leave as 0.
s_TD1.LinkStart         = uint32(1); %See 'Cscope Control Driver DLL description.pdf' for options
s_TD1.LinkTimebase      = uint32(0); %Clock used to run uart, i2C, spi, or digital outputs. In 1/70Mhz units. = 14.29ns.
s_TD1.LinkTimer         = uint32(0); %timer used for repeated messages, in 10us units.
s_TD1.LinkSetup         = uint32(0); %See 'Cscope Control Driver DLL description.pdf' for options
s_TD1.Spare1            = double(0); %Reserved
s_TD1.Spare2            = double(0); %Reserved
s_TD1.Spare3            = double(0); %Reserved
s_TD1.Spare4            = double(0); %Reserved

%%%%%%% Setup structure for TD2 %%%%%%%
% LStr:
% s_LStr.cnt = int32(0);
% s_LStr.str = uint8(0);
% struct_LStr = libstruct('LStr',s_LStr);
% *LStr:
% struct_LStr_Ptr = libpointer('LStrPtr',struct_LStr);
% **LStr:
%struct_LStr_Hdl = libpointer('LStr',s_LStr);
%struct_LStr_Hdl
% TD2:
%s_TD2.status    = uint8(0);
%s_TD2.code      = uint32(0);
%s_TD2.source    = struct_LStr_Hdl;
end

