%%%%%%% ---- Cleverscope library load ---- %%%%%%%

clc % Clear command window
clear all; % Clear workspace variables etc.

% Setup variables:
display_results_in_3d = 0; % Set to 0 for 2D display, or 1 for 3D display.
suppress_status = 1; % set to 1 to stop text being displayed during acquisition;
update_counter = int32(0); % A counter required to be passed to the driver each time the AcquireDefinition is to be changed.
nsamp = int32(2048); % Number of samples to return from acquisition
[ AcquireDefinition ] = InitAcquireDefinition;
pChanAData = libpointer('singlePtr', zeros(nsamp,1,'single')); %4k sample buffer Chan A
pChanBData = libpointer('singlePtr', zeros(nsamp,1,'single')); %4k sample buffer Chan B
pDigData = libpointer('uint16Ptr', zeros(nsamp,1,'uint16')); %4k sample buffer Digital


% Open the cleverscope
[result] = cleverscope_open('cscope');

% Initisalise the cleverscope
if (result)
    [result] = cleverscope_init('cscope',AcquireDefinition);
end

% Wait for hardware to Initialise
if (result)
   [result] = cleverscope_wait_for_init('cscope',AcquireDefinition); 
end

% Update Aquire definition
if (result)
   AcquireDefinition.AcquireMode = uint16(1); % Automatic trigger
   [result, update_counter] = cleverscope_update_acquire_definition('cscope',AcquireDefinition,update_counter);
end

% Perform acquisition, and get samples
for acquire_count = 1:40
    if (result)
        [ result, T0, dt, NumSamples, NumFrames, ...
        ChanAData, ChanBData, DigitalInputData ] = ...
        cleverscope_get_samples( 'cscope', AcquireDefinition, nsamp, pChanAData, pChanBData, pDigData, suppress_status);
    end
   
    % Display the results:
    if (result)
        if display_results_in_3d
            cleverscope_plot_3d_results(T0, dt, NumSamples, NumFrames, ChanAData, ChanBData, DigitalInputData, suppress_status);
        else
            cleverscope_plot_2d_results(T0, dt, NumSamples, NumFrames, ChanAData, ChanBData, DigitalInputData, suppress_status);
        end
    end
end

% Tidy up and Unload
[~] = cleverscope_close( 'cscope', AcquireDefinition );
unloadlibrary('cscope')
